@@ -1,7 +1,7 @@
 #ifndef MTETRIGGERCONF_H
 #define MTETRIGGERCONF_H
 
-config_require(utilities/iquery)
+config_require(utilities/iquery);
 
 /*
  * function declarations 
